SWDEV-327563 - Enable fixed tests linux and windows (#2803)
Change-Id: Icad90d01f796a8a8cf57884b86ca1a5a2b50ec64
[ROCm/hip-tests commit: 1458912363]
Tento commit je obsažen v:
odevzdal
GitHub
rodič
e469c7468f
revize
55f417dcee
@@ -1,10 +1,7 @@
|
||||
{
|
||||
"DisabledTests":
|
||||
[
|
||||
"# Following test is related to ticket EXSWCPHIPT-41",
|
||||
"Unit_hipStreamGetPriority_happy",
|
||||
"Unit_hipStreamPerThread_DeviceReset_1",
|
||||
"Unit_hipGraphAddKernelNode_Negative"
|
||||
"Unit_hipStreamPerThread_DeviceReset_1"
|
||||
]
|
||||
|
||||
}
|
||||
|
||||
@@ -7,8 +7,6 @@
|
||||
"Unit_hipTextureMipmapObj2D_Check",
|
||||
"Unit_hipManagedKeyword_MultiGpu",
|
||||
"Unit_hipGraphAddHostNode_ClonedGraphwithHostNode",
|
||||
"Unit_hipGraphAddChildGraphNode_OrgGraphAsChildGraph",
|
||||
"Unit_hipGraphAddChildGraphNode_SingleChildNode",
|
||||
"Unit_hipEventIpc",
|
||||
"Unit_hipMalloc3D_Negative",
|
||||
"Unit_hipPointerGetAttribute_MappedMem",
|
||||
@@ -27,13 +25,9 @@
|
||||
"Unit_hipMemPoolApi_Opportunistic",
|
||||
"Unit_hipMemPoolApi_Default",
|
||||
"Unit_hipDeviceGetUuid",
|
||||
"Unit_hipGraphMemcpyNodeSetParamsFromSymbol_Functional",
|
||||
"Unit_hipGraphExecEventWaitNodeSetEvent_Negative",
|
||||
"Unit_hipGraphExecEventWaitNodeSetEvent_SetAndVerifyMemory",
|
||||
"Unit_hipGraphMemcpyNodeSetParams_Functional",
|
||||
"Unit_hipMalloc3D_ValidatePitch",
|
||||
"Unit_hipArrayCreate_happy",
|
||||
"Unit_hipGraphAddKernelNode_Negative",
|
||||
"Unit_hipHostRegister_Negative - int",
|
||||
"Unit_hipHostRegister_Negative - float",
|
||||
"Unit_hipHostRegister_Negative - double",
|
||||
|
||||
@@ -49,12 +49,6 @@ TEST_CASE("Unit_hipEventDestroy_NullCheck") {
|
||||
|
||||
TEST_CASE("Unit_hipEventCreate_IncompatibleFlags") {
|
||||
hipEvent_t event;
|
||||
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-106");
|
||||
return;
|
||||
#endif
|
||||
|
||||
HIP_CHECK_ERROR(hipEventCreateWithFlags(&event, hipEventInterprocess), hipErrorInvalidValue);
|
||||
|
||||
#if HT_AMD
|
||||
|
||||
@@ -228,6 +228,7 @@ void hipGraphMemcpyNodeSetParamsFromSymbol_GlobalMem(bool useConstDeviceVar) {
|
||||
// Instantiate and launch the graph
|
||||
HIP_CHECK(hipGraphInstantiate(&graphExec, graph, nullptr, nullptr, 0));
|
||||
HIP_CHECK(hipGraphLaunch(graphExec, 0));
|
||||
HIP_CHECK(hipStreamSynchronize(0));
|
||||
|
||||
// Validating the result
|
||||
for (int i = 0; i < SIZE; i++) {
|
||||
|
||||
@@ -65,10 +65,6 @@ TEST_CASE("Unit_hipHostUnregister_MemoryNotAccessableAfterUnregister") {
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipHostUnregister_NullPtr") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-90");
|
||||
return;
|
||||
#endif
|
||||
HIP_CHECK_ERROR(hipHostUnregister(nullptr), hipErrorInvalidValue);
|
||||
}
|
||||
|
||||
|
||||
@@ -494,10 +494,6 @@ TEMPLATE_TEST_CASE("Unit_hipMallocArray_MaxTexture_Default", "", uint, int4, ush
|
||||
|
||||
// Arrays with channels of different size are not allowed.
|
||||
TEST_CASE("Unit_hipMallocArray_Negative_DifferentChannelSizes") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-129");
|
||||
return;
|
||||
#endif
|
||||
const int bitsX = GENERATE(8, 16, 32);
|
||||
const int bitsY = GENERATE(8, 16, 32);
|
||||
const int bitsZ = GENERATE(8, 16, 32);
|
||||
|
||||
@@ -71,9 +71,6 @@ TEST_CASE("Unit_hipMemset_Negative_InvalidPtr") {
|
||||
|
||||
|
||||
TEST_CASE("Unit_hipMemset_Negative_OutOfBoundsSize") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-20");
|
||||
#endif
|
||||
|
||||
#if !HT_AMD
|
||||
void* dst;
|
||||
@@ -112,10 +109,6 @@ TEST_CASE("Unit_hipMemset2D_Negative_InvalidPtr") {
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipMemset2D_Negative_InvalidSizes") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-52");
|
||||
#endif
|
||||
|
||||
void* dst;
|
||||
size_t realPitch;
|
||||
HIP_CHECK(hipMallocPitch(&dst, &realPitch, width, height));
|
||||
@@ -181,10 +174,6 @@ TEST_CASE("Unit_hipMemset3D_Negative_ModifiedPtr") {
|
||||
}
|
||||
|
||||
TEST_CASE("Unit_hipMemset3D_Negative_InvalidSizes") {
|
||||
#if HT_AMD
|
||||
HipTest::HIP_SKIP_TEST("EXSWCPHIPT-52");
|
||||
#endif
|
||||
|
||||
hipPitchedPtr pitchedDevPtr;
|
||||
HIP_CHECK(hipMalloc3D(&pitchedDevPtr, validExtent));
|
||||
hipExtent invalidExtent{validExtent};
|
||||
|
||||
Odkázat v novém úkolu
Zablokovat Uživatele